linshareapi
============

Description
-----------

This package contains the [LinShare](http://linshare.org "Open Source secure
files sharing application") api.


Installation
------------

You can install this module using : ``pip install linshareapi``.

